from setuptools import Extension, find_packages, setup 
from setuptools.command.build_ext import build_ext
from os import system

def Make():
    system('make -C bulgogi cibuildwheel')

class MakeBuildExt(build_ext):
    def run(self) -> None:
        Make()
        super().run()

setup(
    cmdclass={
        'build_ext': MakeBuildExt,
    },
    ext_modules=[
        Extension(
            name="bulgogi",
            sources=[
                "bulmodule.c", 
            ],
            include_dirs=["bulgogi/inc"],
            library_dirs=["bulgogi/lib"],
            libraries=["bul", "yaml"],
        ),
    ],
    packages=find_packages(where="bulgogi"),
    package_dir={"": "bulgogi"},
    package_data={"lib": ["*.a"]},
    include_package_data=True,
)



#!/usr/bin/env python3
import bulgogi as bul

c = bul.Core(from_file='project.yaml')

print('#-- c.raw_targets(): --#')
for t in c.raw_targets():
    print('Target: ' + t.name)
    for dep in t.deps:
        if dep.name == 'src':
            print('  sources:')
            for src in dep.deps:
                print('    ' + src.name)
        elif dep.name == 'inc':
            print('  include:')
            for inc in dep.deps:
                print('    ' + inc.name)
        elif dep.name == 'dep':
            print('  deps:')
            for d in dep.deps:
                print('    ' + d.name)

print('')
print('#-- c.targets() --#')
for t in c.targets():
    print('Target: ' + t.name)
    for dep in t.deps:
        if dep.name == 'src':
            print('  sources:')
            for src in dep.deps:
                print('    ' + src.name)
        elif dep.name == 'inc':
            print('  include:')
            for inc in dep.deps:
                print('    ' + inc.name)
        elif dep.name == 'dep':
            print('  deps:')
            for d in dep.deps:
                print('    ' + d.name)
